#
# spec file for package initviocons
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           initviocons
Version:        0.5
Release:        107.5
Summary:        Terminal Initialization, e.g. for the iSeries Virtual Console
License:        GPL-2.0-or-later
Group:          System/Console
URL:            http://svn.poeml.de/viewcvs/initviocons/
Source:         initviocons-%{version}.tar.bz2
BuildRequires:  automake

%description
Initviocons can be used on the iSeries platform to recognize terminal
features of a telnet client that is connected to the virtual console
(similar to a serial console). It probes the terminal via escape
sequences to find out the screen size and a suitable TERM type. It also
does special initialization if possible (for example, carriage return
suppression for Windows telnet clients). On the iSeries platform, it
additionally checks for the presence of more than one terminal
connected on the same line. See %{_sysconfdir}/profile for a usage example.

%prep
%setup -q -n initviocons-%{version}

%build
autoreconf -fi
%configure
%make_build CFLAGS="%{optflags} -Wall"

%install
%make_install
install -m 0755 termprobes %{buildroot}/%{_bindir}/termprobes
%if 0%{?suse_version} < 1550
mkdir -p %{buildroot}/bin
ln -sf %{_bindir}/initviocons %{buildroot}/bin
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%if 0%{?suse_version} < 1550
/bin/*
%endif
%{_bindir}/*

%changelog
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- spec-cleaner run
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Fri Oct 16 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Wed May 31 2017 meissner@suse.com
- Actually build with RPM_OPT_FLAGS, will also catch
  too long -F arguments (bsc#1041840)
* Fri Feb 17 2012 rschweikert@suse.com
- place binary in /usr tree (UsrMerge project)
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Oct  5 2009 poeml@suse.de
- add missing executable permissions to /usr/bin/termprobes
  [bnc#544224]
* Mon Dec 10 2007 poeml@suse.de
- update to r27:
  - when using -e, only output the TERM value and don't add
    LINES,COLUMNS by default anymore. Discussion in [#184179] (ssh
    installation exit abnormally when change terminal window size)
    has shown that they are not needed anyway, and they seem to
    cause problems in some cases (when used together with ssh).  In
    order to be able to revert to the previous behaviour, the -s
    switch was added. It adds LINES and COLUMNS to the eval output
    again.
* Wed Nov 14 2007 poeml@suse.de
- update to r25:
  - recognize WebSM console
    https://bugzilla.novell.com/show_bug.cgi?id=256139
    which sends a characteristic primary da
* Thu Jul 19 2007 poeml@suse.de
- update to 0.5 (svn r24)
  - support for mlterm and Terminal.app
  - prefer Terminal.app over kterm (which responds in the same
    way). kterm is not widely used anymore, it was an old xterm
    fork but it isn't UTF-8 capable.
  - make it compile on Darwin 8.6
  - fold in patches initviocons-0.4.dif (c shell eval mode)
    initviocons.minimal-termsize.patch [#140383]
    initviocons.ps3-hack.patch
    initviocons.ps3-matching.patch
* Tue Jul 17 2007 sassmann@suse.de
- added new /proc/device-tree/model matching for ps3 detection
* Tue Apr 24 2007 olh@suse.de
- do not run initviocons on PS3, until the kernel fb is fixed
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan  8 2006 olh@suse.de
- do not set cols/rows to less than 80x24 (#140383)
* Wed Oct 26 2005 werner@suse.de
- Add support for C shell in eval mode
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Sun Jun  9 2002 poeml@suse.de
- update to 0.4
- no longer ignore carriage return when a Windows telnet client ist
  connected (on iSeries). The telnet server has been fixed to
  handle the Network Virtual Terminal newline correctly.  If the
  respective Program Temporary Fixes are installed on the iSeries,
  this fix here is needed as well to prevent Enter key malfunction
  on the virtual console.
* Tue Mar 12 2002 kukuk@suse.de
- Fix filelist (exclude /usr/bin as directory)
* Mon Feb  4 2002 poeml@suse.de
- created package
